updater

package
v0.0.0-...-1cf95b6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: AGPL-3.0 Imports: 28 Imported by: 0

Documentation

Rendered for windows/amd64

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DownloadVerifyAndExecute

func DownloadVerifyAndExecute(userToken uintptr) (progress chan DownloadProgress)

func StartBackgroundUpdateChecker

func StartBackgroundUpdateChecker(interval time.Duration, callback UpdateFoundCallback)

StartBackgroundUpdateChecker starts a background goroutine that checks for updates at the specified interval. When an update is found, it calls the provided callback. The function performs an initial check after a 30 second delay, then checks at the specified interval thereafter.

Types

type DownloadProgress

type DownloadProgress struct {
	Activity        string
	BytesDownloaded uint64
	BytesTotal      uint64
	Error           error
	Complete        bool
}

type UpdateFound

type UpdateFound struct {
	// contains filtered or unexported fields
}

func CheckForUpdate

func CheckForUpdate() (updateFound *UpdateFound, err error)

func (*UpdateFound) Name

func (u *UpdateFound) Name() string

Name returns the filename of the update MSI

type UpdateFoundCallback

type UpdateFoundCallback func(update *UpdateFound)

UpdateFoundCallback is a function type that gets called when an update is found

Directories

Path Synopsis

Jump to