Documentation
¶
Rendered for windows/amd64
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DownloadVerifyAndExecute ¶
func DownloadVerifyAndExecute(userToken uintptr) (progress chan DownloadProgress)
func StartBackgroundUpdateChecker ¶
func StartBackgroundUpdateChecker(interval time.Duration, callback UpdateFoundCallback)
StartBackgroundUpdateChecker starts a background goroutine that checks for updates at the specified interval. When an update is found, it calls the provided callback. The function performs an initial check after a 30 second delay, then checks at the specified interval thereafter.
Types ¶
type DownloadProgress ¶
type UpdateFound ¶
type UpdateFound struct {
// contains filtered or unexported fields
}
func CheckForUpdate ¶
func CheckForUpdate() (updateFound *UpdateFound, err error)
func (*UpdateFound) Name ¶
func (u *UpdateFound) Name() string
Name returns the filename of the update MSI
type UpdateFoundCallback ¶
type UpdateFoundCallback func(update *UpdateFound)
UpdateFoundCallback is a function type that gets called when an update is found
Source Files
¶
Click to show internal directories.
Click to hide internal directories.